@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: PageInfoPrivate.cpp 1400 2006-12-08 20:01:54Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -23,8 +23,12 @@
 
 #include <nscore.h>
 
+#ifdef HAVE_GECKO_1_9
+#include <nsStringGlue.h>
+#else
 #define MOZILLA_INTERNAL_API 1
 #include <nsString.h>
+#endif /* HAVE_GECKO_1_9 */
 
 #include <nsCOMPtr.h>
 #include <nsIDOMDocument.h>
